@@ -68,6 +68,16 @@ func mainInner() error {
 	}
 	fmt.Printf("Stores Count: %d\n", len(stores.Stores))
 
+	// ListStores with name filter
+	fmt.Println("Listing Stores with name filter")
+	storesWithFilter, err := fgaClient.ListStores(ctx).Options(client.ClientListStoresOptions{
+		Name: openfga.PtrString("Test Store"),
+	}).Execute()
+	if err != nil {
+		return err
+	}
+	fmt.Printf("Stores with name filter Count: %d\n", len(storesWithFilter.Stores))
+
 	// GetStore
 	fmt.Println("Getting Current Store")
 	currentStore, err := fgaClient.GetStore(ctx).Execute()
@@ -190,6 +200,10 @@ func mainInner() error {
 		},
 	}).Options(client.ClientWriteOptions{
 		AuthorizationModelId: &authorizationModel.AuthorizationModelId,
+		Conflict: client.ClientWriteConflictOptions{
+			// We can choose to ignore conflicts during writes
+			OnDuplicateWrites: client.CLIENT_WRITE_REQUEST_ON_DUPLICATE_WRITES_IGNORE,
+		},
 	}).Execute()
 	if err != nil {
 		return err
@@ -244,6 +258,52 @@ func mainInner() error {
 	}
 	fmt.Printf("Allowed: %v\n", checkResponse.Allowed)
 
+	fmt.Println("Checking for access with custom headers")
+	checkWithHeadersResponse, err := fgaClient.Check(ctx).Body(client.ClientCheckRequest{
+		User:     "user:anne",
+		Relation: "viewer",
+		Object:   "document:0192ab2a-d83f-756d-9397-c5ed9f3cb69a",
+		Context:  &map[string]interface{}{"ViewCount": 100},
+	}).Options(client.ClientCheckOptions{
+		RequestOptions: client.RequestOptions{
+			Headers: map[string]string{
+				"X-Request-ID": "example-request-123",
+			},
+		},
+	}).Execute()
+	if err != nil {
+		return err
+	}
+	fmt.Printf("Allowed (with custom headers): %v\n", checkWithHeadersResponse.Allowed)
+
+	// BatchCheck
+	fmt.Println("Batch checking for access")
+	batchCheckResponse, err := fgaClient.BatchCheck(ctx).Body(client.ClientBatchCheckRequest{
+		Checks: []client.ClientBatchCheckItem{
+			{
+				CorrelationId: "f278708f-298c-4f43-a893-11a02bbf251c",
+				User:          "user:anne",
+				Relation:      "viewer",
+				Object:        "document:0192ab2a-d83f-756d-9397-c5ed9f3cb69a",
+				Context:       &map[string]interface{}{"ViewCount": 100},
+			},
+			{
+				CorrelationId: "9f7563d6-2573-4292-9ba2-62d59b97c4d",
+				User:          "user:bob",
+				Relation:      "viewer",
+				Object:        "document:0192ab2a-d83f-756d-9397-c5ed9f3cb69a",
+				Context:       &map[string]interface{}{"ViewCount": 100},
+			},
+		},
+	}).Execute()
+	if err != nil {
+		return err
+	}
+	fmt.Println("BatchCheck results:")
+	for correlationID, result := range batchCheckResponse.GetResult() {
+		fmt.Printf("Correlation %s - Allowed: %v\n", correlationID, result.GetAllowed())
+	}
+
 	// ListObjects
 	fmt.Println("Listing objects user has access to")
 	listObjectsResponse, err := fgaClient.ListObjects(ctx).Body(client.ClientListObjectsRequest{
