@@ -8,7 +8,6 @@ import (
 	"context"
 	"fmt"
 	"io"
-	"log"
 	"math"
 	"net/http"
 	"net/http/httptest"
@@ -16,8 +15,24 @@ import (
 	"testing"
 
 	"github.com/jarcoal/httpmock"
+
+	"github.com/openfga/go-sdk/internal/utils/retryutils"
 )
 
+const (
+	testMaxRetry    = 2
+	testMinWaitInMs = 20
+	testURL         = "https://auth.fga.example"
+)
+
+var testTokenRequestConfig = RequestConfig{
+	RetryParams: retryutils.RetryParams{
+		MaxRetry:    testMaxRetry,
+		MinWaitInMs: testMinWaitInMs,
+	},
+	Debug: false,
+}
+
 func TestRetrieveToken_InParams(t *testing.T) {
 	ResetAuthCache()
 	const clientID = "client-id"
@@ -29,10 +44,15 @@ func TestRetrieveToken_InParams(t *testing.T) {
 			t.Errorf("client_secret = %q; want empty", got)
 		}
 		w.Header().Set("Content-Type", "application/json")
-		io.WriteString(w, `{"access_token": "ACCESS_TOKEN", "token_type": "bearer"}`)
+		_, _ = io.WriteString(w, `{"access_token": "ACCESS_TOKEN", "token_type": "bearer"}`)
 	}))
 	defer ts.Close()
-	_, err := RetrieveToken(context.Background(), clientID, "", ts.URL, url.Values{}, AuthStyleInParams)
+	_, err := RetrieveToken(context.Background(), clientID, "", ts.URL, url.Values{}, AuthStyleInParams, RequestConfig{
+		RetryParams: retryutils.RetryParams{
+			MaxRetry:    1,
+			MinWaitInMs: testMinWaitInMs,
+		},
+	})
 	if err != nil {
 		t.Errorf("RetrieveToken = %v; want no error", err)
 	}
@@ -44,11 +64,11 @@ func TestRetrieveTokenWithContexts(t *testing.T) {
 
 	ts := httptest.NewServer(http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		w.Header().Set("Content-Type", "application/json")
-		io.WriteString(w, `{"access_token": "ACCESS_TOKEN", "token_type": "bearer"}`)
+		_, _ = io.WriteString(w, `{"access_token": "ACCESS_TOKEN", "token_type": "bearer"}`)
 	}))
 	defer ts.Close()
 
-	_, err := RetrieveToken(context.Background(), clientID, "", ts.URL, url.Values{}, AuthStyleUnknown)
+	_, err := RetrieveToken(context.Background(), clientID, "", ts.URL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	if err != nil {
 		t.Errorf("RetrieveToken (with background context) = %v; want no error", err)
 	}
@@ -61,7 +81,7 @@ func TestRetrieveTokenWithContexts(t *testing.T) {
 
 	ctx, cancel := context.WithCancel(context.Background())
 	cancel()
-	_, err = RetrieveToken(ctx, clientID, "", cancellingts.URL, url.Values{}, AuthStyleUnknown)
+	_, err = RetrieveToken(ctx, clientID, "", cancellingts.URL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	close(retrieved)
 	if err == nil {
 		t.Errorf("RetrieveToken (with cancelled context) = nil; want error")
@@ -87,17 +107,55 @@ func TestRetrieveTokenWithContextsRetry(t *testing.T) {
 	firstMock := httpmock.NewStringResponder(429, "")
 	secondMock, _ := httpmock.NewJsonResponder(200, expectedResponse)
 
-	const testURL = "http://testserver.com"
 	httpmock.RegisterResponder("POST", testURL,
 		firstMock.Then(firstMock).Then(firstMock).Then(secondMock),
 	)
 
-	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleUnknown)
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, RequestConfig{
+		RetryParams: retryutils.RetryParams{
+			MaxRetry:    3,
+			MinWaitInMs: testMinWaitInMs,
+		},
+	})
 	if err != nil {
 		t.Errorf("RetrieveToken (with background context) = %v; want no error", err)
 	}
 }
 
+// Test the retry logic where request is successful at the end
+func TestRetrieveTokenWithContextsRetryMaxExceeded(t *testing.T) {
+	ResetAuthCache()
+	const clientID = "client-id"
+
+	type JSONResponse struct {
+		AccessToken string `json:"access_token"`
+		TokenType   string `json:"token_type"`
+	}
+	expectedResponse := JSONResponse{
+		AccessToken: "ACCESS_TOKEN",
+		TokenType:   "bearer",
+	}
+
+	httpmock.Activate()
+	defer httpmock.DeactivateAndReset()
+	firstMock := httpmock.NewStringResponder(429, "")
+	secondMock, _ := httpmock.NewJsonResponder(200, expectedResponse)
+
+	httpmock.RegisterResponder("POST", testURL,
+		firstMock.Then(firstMock).Then(firstMock).Then(secondMock),
+	)
+
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, RequestConfig{
+		RetryParams: retryutils.RetryParams{
+			MaxRetry:    2,
+			MinWaitInMs: testMinWaitInMs,
+		},
+	})
+	if err == nil {
+		t.Errorf("RetrieveToken (with background context); expected error after exceeding max retries, got none")
+	}
+}
+
 func TestRetrieveTokenWithContextsFailure(t *testing.T) {
 	ResetAuthCache()
 	const clientID = "client-id"
@@ -111,12 +169,11 @@ func TestRetrieveTokenWithContextsFailure(t *testing.T) {
 	defer httpmock.DeactivateAndReset()
 	firstMock := httpmock.NewStringResponder(429, "")
 
-	const testURL = "http://testserver.com"
 	httpmock.RegisterResponder("POST", testURL,
 		firstMock,
 	)
 
-	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleUnknown)
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	if err == nil {
 		t.Errorf("Expect error to be returned when oauth server fails consistently")
 	}
@@ -131,21 +188,18 @@ func TestRetrieveTokenWithUnauthorizedErrors(t *testing.T) {
 	defer httpmock.DeactivateAndReset()
 	firstMock := httpmock.NewStringResponder(401, "")
 
-	const testURL = "http://testserver.com"
 	httpmock.RegisterResponder("POST", testURL,
 		firstMock,
 	)
 
-	// Set AuthStyleInHeader to avoid making a discovery request
-	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInHeader)
+	// Set AuthStyleInParams to avoid making a discovery request
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	if err == nil {
 		t.Errorf("Expect error to be returned when oauth server fails consistently")
 	}
 
-	log.Print(httpmock.GetTotalCallCount())
-
 	if httpmock.GetTotalCallCount() != 1 {
-		t.Errorf("Expected request to not be retried on a 401")
+		t.Errorf("Expected request to be called once and not be retried on a 401, it was called %v times", httpmock.GetTotalCallCount())
 	}
 }
 
@@ -168,12 +222,12 @@ func TestRetrieveTokenWithServerErrorRetries(t *testing.T) {
 	firstMock := httpmock.NewStringResponder(500, "")
 	secondMock, _ := httpmock.NewJsonResponder(200, expectedResponse)
 
-	const testURL = "http://testserver.com"
 	httpmock.RegisterResponder("POST", testURL,
-		firstMock.Then(firstMock).Then(firstMock).Then(secondMock),
+		firstMock.Then(firstMock).Then(secondMock),
 	)
 
-	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleUnknown)
+	// Set AuthStyleInParams to avoid making a discovery request
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	if err != nil {
 		t.Errorf("RetrieveToken (with background context) = %v; want no error", err)
 	}
@@ -188,21 +242,19 @@ func TestRetrieveTokenWithServerErrorEventuallyErrors(t *testing.T) {
 	defer httpmock.DeactivateAndReset()
 	firstMock := httpmock.NewStringResponder(500, "")
 
-	const testURL = "http://testserver.com"
 	httpmock.RegisterResponder("POST", testURL,
 		firstMock,
 	)
 
-	// Set AuthStyleInHeader to avoid making a discovery request
-	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInHeader)
+	// Set AuthStyleInParams to avoid making a discovery request
+	_, err := RetrieveToken(context.Background(), clientID, "", testURL, url.Values{}, AuthStyleInParams, testTokenRequestConfig)
 	if err == nil {
 		t.Errorf("Expect error to be returned when oauth server fails consistently")
 	}
 
-	log.Print(httpmock.GetTotalCallCount())
-
-	if httpmock.GetTotalCallCount() != cMaxRetry {
-		t.Errorf("Expected request to not be retried on a 401")
+	// Expect the request to be called once and then retried testMaxRetry times
+	if httpmock.GetTotalCallCount() != testMaxRetry+1 {
+		t.Errorf("Expected request to be retried %v times on a 500, it was retried %v", testMaxRetry, httpmock.GetTotalCallCount()-1)
 	}
 }
 
